@@ -18,13 +18,36 @@ describe_chemical <- function(chem_id) {
 
   url_root <- 'https://data.rcsb.org/rest/v1/core/chemcomp/'
   url <- paste0(url_root, chem_id)
-  response <- GET(url)
+
+  response <- tryCatch(
+    {
+      GET(url)
+    },
+    error = function(e) {
+      warning("Failed to retrieve data: ", e$message)
+      return(NULL)
+    }
+  )
+
+  if (is.null(response)) {
+    return(NULL)
+  }
 
   if (http_status(response)$category != "Success") {
     stop("Retrieval failed: ", http_status(response)$reason)
   }
 
-  out <- fromJSON(content(response, "text", encoding = "UTF-8"))
+  out <- tryCatch(
+    {
+      fromJSON(content(response, "text", encoding = "UTF-8"))
+    },
+    error = function(e) {
+      warning("Failed to parse JSON response: ", e$message)
+      return(NULL)
+    }
+  )
+
   return(out)
 }
 
+
