@@ -16,21 +16,45 @@
 #' }
 #' @export
 find_papers <- function(search_term, max_results = 10) {
-  # Assuming Query and get_info functions are already defined in R
+  # Assuming query_search and get_info functions are already defined in R
 
   all_papers <- list()
-  id_list <- query_search(search_term)
 
-  pdbIds = id_list[1:max_results]
+  # Error handling for the query search
+  id_list <- tryCatch(
+    {
+      query_search(search_term)
+    },
+    error = function(e) {
+      warning("Failed to fetch search results: ", e$message)
+      return(NULL)
+    }
+  )
+
+  if (is.null(id_list)) {
+    return(all_papers)
+  }
+
+  # Limit the number of results to max_results
+  pdbIds <- id_list[1:min(max_results, length(id_list))]
 
   for (i in 1:length(pdbIds)) {
-    pdb_info <- get_info(pdbIds[i])
-    if ("citation" %in% names(pdb_info)) {
+    # Error handling for fetching individual paper info
+    pdb_info <- tryCatch(
+      {
+        get_info(pdbIds[i])
+      },
+      error = function(e) {
+        warning("Failed to fetch information for ID ", pdbIds[i], ": ", e$message)
+        return(NULL)
+      }
+    )
 
+    if (!is.null(pdb_info) && "citation" %in% names(pdb_info)) {
       all_papers[[pdbIds[i]]] <- pdb_info$citation$title[1]
     }
   }
 
-  return((all_papers))
+  return(all_papers)
 }
 
