@@ -12,18 +12,39 @@
 #' @examples
 #' get_fasta_from_rcsb_entry(c("4HHB"), verbosity = TRUE)
 #' @export
-
 get_fasta_from_rcsb_entry <- function(rcsb_id, verbosity = TRUE) {
   if (verbosity) {
     message(sprintf("Querying RCSB for the '%s' FASTA file.", rcsb_id))
   }
 
-  response <- GET(paste0(FASTA_BASE_URL, rcsb_id))
+  response <- tryCatch(
+    {
+      GET(paste0(FASTA_BASE_URL, rcsb_id))
+    },
+    error = function(e) {
+      warning("Failed to retrieve data: ", e$message)
+      return(NULL)
+    }
+  )
 
-  if (http_status(response)$category != "Success") {
-    stop("Request failed with:", content(response, "text", encoding = "UTF-8"))
+  if (is.null(response)) {
+    return(NULL)
   }
 
-  fasta_sequences <- parse_fasta_text_to_list(content(response, "text", encoding = "UTF-8"))
+  if (http_status(response)$category != "Success") {
+    warning("Request failed with: ", content(response, "text", encoding = "UTF-8"))
+    return(NULL)
+  }
+
+  fasta_sequences <- tryCatch(
+    {
+      parse_fasta_text_to_list(content(response, "text", encoding = "UTF-8"))
+    },
+    error = function(e) {
+      warning("Failed to parse FASTA response: ", e$message)
+      return(NULL)
+    }
+  )
+
   return(fasta_sequences)
 }
